"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.downloadTailsFile = exports.tailsFileExists = void 0;
const core_1 = require("@aries-framework/core");
const getTailsFilePath = (cachePath, tailsHash) => `${cachePath}/anoncreds/tails/${tailsHash}`;
function tailsFileExists(agentContext, tailsHash) {
    const fileSystem = agentContext.dependencyManager.resolve(core_1.InjectionSymbols.FileSystem);
    const tailsFilePath = getTailsFilePath(fileSystem.cachePath, tailsHash);
    return fileSystem.exists(tailsFilePath);
}
exports.tailsFileExists = tailsFileExists;
async function downloadTailsFile(agentContext, tailsLocation, tailsHashBase58) {
    const fileSystem = agentContext.dependencyManager.resolve(core_1.InjectionSymbols.FileSystem);
    try {
        agentContext.config.logger.debug(`Checking to see if tails file for URL ${tailsLocation} has been stored in the FileSystem`);
        // hash is used as file identifier
        const tailsExists = await tailsFileExists(agentContext, tailsHashBase58);
        const tailsFilePath = getTailsFilePath(fileSystem.cachePath, tailsHashBase58);
        agentContext.config.logger.debug(`Tails file for ${tailsLocation} ${tailsExists ? 'is stored' : 'is not stored'} at ${tailsFilePath}`);
        if (!tailsExists) {
            agentContext.config.logger.debug(`Retrieving tails file from URL ${tailsLocation}`);
            // download file and verify hash
            await fileSystem.downloadToFile(tailsLocation, tailsFilePath, {
                verifyHash: {
                    algorithm: 'sha256',
                    hash: core_1.TypedArrayEncoder.fromBase58(tailsHashBase58),
                },
            });
            agentContext.config.logger.debug(`Saved tails file to FileSystem at path ${tailsFilePath}`);
        }
        return {
            tailsFilePath,
        };
    }
    catch (error) {
        agentContext.config.logger.error(`Error while retrieving tails file from URL ${tailsLocation}`, {
            error,
        });
        throw error;
    }
}
exports.downloadTailsFile = downloadTailsFile;
//# sourceMappingURL=tails.js.map